<?php
// $Id: statspro_settings.inc,v 1.1.2.6 2010/06/16 22:29:14 rsevero Exp $

/**
 * @file
 *   General settings help methods.
 *
 */

function set_default_session_values($suffix, $period = '', $number_of_days = NULL) {
  $index = 'statspro_period' . $suffix;
  if (array_key_exists($period, statspro_get_period_items())) {
    $_SESSION[$index] = $period;
  }
  elseif (!isset($_SESSION[$index])) {
    $_SESSION[$index] = variable_get('statspro_period', 'today');
  }

  $index = 'statspro_custom_number_days' . $suffix;
  if (is_numeric($number_of_days)) {
    $_SESSION[$index] = (int) $number_of_days;
  }
  elseif (!isset($_SESSION[$index])) {
    $_SESSION[$index] = variable_get('statspro_custom_number_days', 30);
  }
}

/**
 * Form generating function for report settings.
 */
function statspro_settings_form($default_period, $default_custom_days) {
  $form = array();

  $form['statspro_period'] = array(
    '#type' => 'select',
    '#title' => t('Time period'),
    '#default_value' => $default_period,
    '#options' => statspro_get_period_items(),
  );

  $form['statspro_custom_number_days'] = array(
    '#type' => 'textfield',
    '#title' => t('Custom number of days'),
    '#default_value' => $default_custom_days,
    '#size' => 4,
    '#maxlength' => 4,
    '#description' => t('Number of past days from today to include.'),
  );

  $form['#validate'] = array('statspro_settings_form_validate');

  $form['buttons']['submit'] = array('#type' => 'submit', '#value' => t('Save configuration') );
  $form['buttons']['reset'] = array('#type' => 'submit', '#value' => t('Reset to defaults') );

  if (!empty($_POST) && form_get_errors()) {
    drupal_set_message(t('The settings have not been saved because of the errors.'), 'error');
  }
  $form['#theme'] = 'system_settings_form';

  drupal_add_js(drupal_get_path('module', 'statspro') . '/statspro_common_settings.js');

  return $form;
}

/**
 * Implementation of hook_modulename_validate() for settings form.
 */
function statspro_settings_form_validate($form, &$form_state) {
  $periods = statspro_get_period_items();
  if (!in_array($form_state['values']['statspro_period'], array_keys($periods))) {
    form_set_error(
      'statspro_period',
      t(
        "Unknown period '@period'.",
        array('@period' => $form_state['values']['statspro_period'])
      )
    );
  }
  elseif ($form_state['values']['statspro_period'] == 'custom_days') {
    if (!is_numeric($form_state['values']['statspro_custom_number_days'])) {
      form_set_error(
        'statspro_custom_number_days',
        t(
          "You must set the a numeric value for the number of days for period '@period'.",
          array('@period' => $periods['custom_days'])
        )
      );
    }
    elseif ($form_state['values']['statspro_custom_number_days'] < 0) {
      form_set_error(
        'statspro_custom_number_days',
        t(
          "You must set a non negative number of days for period '@period'.",
          array('@period' => $periods['custom_days'])
        )
      );
    }
  }
}

function statspro_path_aggregated_mandatory() {
  $has_error = FALSE;

  if (module_exists('statistics')) {
    if (variable_get('statistics_enable_access_log', 0) == 0) {
      // Statistics module enabled but access log disabled.
      $message = t(
"The core %statistics_module module is enabled but the %access_log_setting
  setting in the !access_log page isn't. You can't have path aggregated
  statistics without it. Please consider enabling it to enable path aggregated
  reports. Remember that you should not discard access logs for as long as you
  want path aggregated reports.",
          array(
            '%statistics_module' => t('Statistics'),
            '%access_log_setting' => t('Enable access log'),
            '!access_log' => l(t('Access log settings'), 'admin/reports/settings'),
          )
        );
      drupal_set_message($message, 'error');
      $has_error = TRUE;
    }
  }
  else {
    // Statistics module disabled.
    $message = t(
"The core %statistics_module module is not enabled. You can't have path
  aggregated statistics without it. Please consider enabling it and the
  %access_log_setting setting in the %access_log page. Remember that you should
  not discard access logs for as long as you want path aggregated reports.",
        array(
          '%statistics_module' => t('Statistics'),
          '%access_log_setting' => t('Enable access log'),
          '%access_log' => t('Access log settings'),
        )
      );
    drupal_set_message($message, 'error');
    $has_error = TRUE;
  }

  return $has_error;
}

function statspro_path_aggregated_optional() {
  if (!module_exists('statistics_advanced')) {
    // Statistics Advanced module is recommended.
    $message = t(
"The !statistics_advanced_module module is recommended as it fixes core
  %statistics_module module bugs. Please consider installing and enabling it.",
        array(
          '!statistics_advanced_module' => l(t('Statistics Advanced'), 'http://drupal.org/project/statistics_advanced'),
          '%statistics_module' => t('Statistics'),
        )
    );
    drupal_set_message($message, 'warning');
  }

  if (!module_exists('browscap')) {
    $message = t(
"The !browscap_module module is recommended as with it the
  %statistics_advanced_module module can separate regular traffic from webcrawler
  traffic. Please consider installing and enabling it.",
        array(
          '!browscap_module' => l(t('Browscap'), 'http://drupal.org/project/browscap'),
          '%statistics_advanced_module' => t('Statistics Advanced'),
        )
    );
    drupal_set_message($message, 'warning');
  }
}
